@@ -207,10 +207,7 @@ function setupKeyboardFriendlyNavigation() {
 
 function loadShortbread() {
 	if (typeof AWSCShortbread !== "undefined") {
-		const shortbread = AWSCShortbread({
-			// If you're testing in your dev environment, use ".cloudfront.net" for domain, else "boto3.amazonaws.com"
-			domain: "boto3.amazonaws.com",
-		});
+		const shortbread = AWSCShortbread();
 
 		// Check for cookie consent
 		shortbread.checkForCookieConsent();
